package com.poststats.rs.api;

import com.poststats.rs.api.model.Facility;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Positive;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.MediaType;

/**
 * @author brian.long@poststats.com
 */
@Path("/facility/{facilityId}")
@Tag(name = "Facility API")
@Produces({MediaType.APPLICATION_JSON, Constants.V1_JSON})
@ApiResponse(responseCode = "200", description = "Success", content = {
        @Content(mediaType = MediaType.APPLICATION_JSON),
        @Content(mediaType = Constants.V1_JSON)
})
@ApiResponse(responseCode = "400", description = "A request parameter is not valid")
@ApiResponse(responseCode = "404", description = "No matching facility was found")
public interface FacilityApi {

	@GET
	@Operation(
			summary = "Retrieves limited meta-data about a facility.",
			description = "Retreives name, location, and other direct meta-data about the specified facility."
	)
	Facility get(@Parameter(description = "A unique identifier for a facility") @NotNull @Positive @PathParam("facilityId") int facilityId);

}
