package com.poststats.rs.api;

import java.io.InputStream;
import java.math.BigInteger;

import org.apache.http.HttpHeaders;

import com.poststats.rs.api.model.Person;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.security.RolesAllowed;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Positive;
import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.HeaderParam;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.MediaType;

/**
 * @author brian.long@poststats.com
 */
@Path("/person/{personId}")
@Tag(name = "Person API")
@Produces({MediaType.APPLICATION_JSON, Constants.V1_JSON})
@ApiResponse(responseCode = "200", description = "Success", content = {
        @Content(mediaType = MediaType.APPLICATION_JSON),
        @Content(mediaType = Constants.V1_JSON)
})
@ApiResponse(responseCode = "400", description = "A request parameter is not valid")
@ApiResponse(responseCode = "404", description = "No matching person was found")
public interface PersonApi {

	@GET
	@Produces(Constants.V1_JSON)
	@Operation(
			summary = "Retrieves limited meta-data about a person.",
			description = "Retreives name, location, contact, and other direct meta-data about the specified registered person."
	)
	Person get(@Parameter(description = "A unique identifier for a person")
	        @NotNull @Positive @PathParam("personId") long personId);

	@Path("/photo")
	@POST
	@Consumes({"image/png", "image/jpeg"})
    @Produces(Constants.V1_JSON)
	@Operation(
			summary = "Stores a photo of a person.",
			description = "Auto-crops, scales, and stores the specified profile photo and associates the photo to the specified person."
	)
	@RolesAllowed({Constants.ADMIN_ROLE, Constants.MANAGER_ROLE})
	@SecurityRequirement(name = "basic")
	BigInteger uploadProfilePhoto(@Parameter(description = "A unique identifier for a person")
            @NotNull @Positive @PathParam("personId") long personId,
			@Parameter(hidden = true) @HeaderParam(HttpHeaders.CONTENT_TYPE) String contentType,
			@Parameter(description = "A file of the photo") @NotNull InputStream istream);

}
