package com.poststats.rs.api.model;

import java.util.LinkedList;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.poststats.rs.api.annotation.MapEntry;

/**
 * @author brian.long@poststats.com
 */
public abstract class BasePhoto<ConcreteT extends BasePhoto<ConcreteT>> extends BaseModel<ConcreteT> {

	public enum Type {
		@JsonProperty("profile")
		@MapEntry("profile")
		Profile,
		@JsonProperty("nearly-square")
		@MapEntry("nearly-square")
		NearlySquare,
		@JsonProperty("vertical")
		@MapEntry("vertical")
		Vertical,
		@JsonProperty("horizontal")
		@MapEntry("horizontal")
		Horizontal,
		@JsonProperty("logo")
		@MapEntry("logo")
		Logo,
		@JsonProperty("banner")
		@MapEntry("banner")
		Banner,
		@JsonProperty("full")
		@MapEntry("full")
		Full
	}

	@JsonProperty(required = true)
	@MapEntry("photoSizeSID")
	private Type type;

	@JsonProperty
	@MapEntry("title")
	private String caption;

	@JsonProperty
	@MapEntry
	private String description;

	@JsonProperty
	private List<Integer> facilityIds;

	@JsonProperty
	private List<Long> personIds;

	public Type getType() {
		return type;
	}

	public void setType(Type type) {
		this.type = type;
	}

	public String getCaption() {
		return caption;
	}

	public void setCaption(String caption) {
		this.caption = caption;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public List<Integer> getFacilityIds() {
		return facilityIds;
	}

	public void setFacilityIds(List<Integer> facilityIds) {
		this.facilityIds = facilityIds;
	}

	public List<Long> getPersonIds() {
		return personIds;
	}

	public void setPersonIds(List<Long> personIds) {
		this.personIds = personIds;
	}

	public ConcreteT withType(Type type) {
		this.type = type;
		return this.withThis();
	}

	public ConcreteT withCaption(String caption) {
		this.caption = caption;
		return this.withThis();
	}

	public ConcreteT withDescription(String description) {
		this.description = description;
		return this.withThis();
	}

	public ConcreteT withFacilityId(int facilityId) {
		if (this.facilityIds == null)
			this.facilityIds = new LinkedList<>();
		this.facilityIds.add(facilityId);
		return this.withThis();
	}

	public ConcreteT withPersonId(long personId) {
		if (this.personIds == null)
			this.personIds = new LinkedList<>();
		this.personIds.add(personId);
		return this.withThis();
	}

}
