package com.poststats.rs.api.model;

import java.time.LocalDate;
import java.time.OffsetDateTime;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonProperty.Access;
import com.poststats.rs.api.Constants;
import com.poststats.rs.api.annotation.GeocodeSource;
import com.poststats.rs.api.annotation.GeocodeTarget;
import com.poststats.rs.api.annotation.GeocodeTarget.GeocodeField;
import com.poststats.rs.api.annotation.MapCondition;
import com.poststats.rs.api.annotation.MapEntry;

/**
 * @author brian.long@poststats.com
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public class Facility extends BaseFacility<Facility> implements ReferenceableFacility, PeriodConstrainable<LocalDate> {

	@JsonProperty(required = true, access = Access.READ_ONLY)
	@MapEntry("facilityID")
	private int id;

	@JsonProperty(required = true)
	@MapEntry("suffixAbbrev")
	private String nameSuffixAbbrev;

	@MapEntry
	@GeocodeTarget(GeocodeField.AddressLines)
	private String addrlines;

	@MapEntry
	@GeocodeTarget(GeocodeField.City)
	private String addrcity;

	@MapEntry
	@GeocodeTarget(GeocodeField.State)
	private String addrstate;

	@MapEntry
	@GeocodeTarget(GeocodeField.Country)
	private String addrcountry;

	@MapEntry
	@GeocodeTarget(GeocodeField.PostalCode)
	private String addrzip;

	@JsonProperty
	@MapEntry("liveline")
	@MapCondition(rolesAllowed = {
			Constants.ADMIN_ROLE, "course"
	})
	private LocalDate liveline;

	@JsonProperty
	@MapEntry("deadline")
	@MapCondition(rolesAllowed = {
			Constants.ADMIN_ROLE, "course"
	})
	private LocalDate deadline;

	@JsonProperty(access = Access.READ_ONLY)
	@MapEntry("created")
	@MapCondition(rolesAllowed = {
			Constants.ADMIN_ROLE, "course"
	})
	private OffsetDateTime created;

	@Override
	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public String getNameSuffixAbbrev() {
		return nameSuffixAbbrev;
	}

	public void setNameSuffixAbbrev(String nameSuffixAbbrev) {
		this.nameSuffixAbbrev = nameSuffixAbbrev;
	}

	@Override
	@GeocodeSource
	public String getPostalAddress() {
		return super.getPostalAddress();
	}

	@Override
	public LocalDate getLiveline() {
		return liveline;
	}

	@Override
	public void setLiveline(LocalDate liveline) {
		this.liveline = liveline;
	}

	@Override
	public LocalDate getDeadline() {
		return deadline;
	}

	@Override
	public void setDeadline(LocalDate deadline) {
		this.deadline = deadline;
	}

	public OffsetDateTime getCreated() {
		return created;
	}

	public void setCreated(OffsetDateTime created) {
		this.created = created;
	}

	public Facility withId(int id) {
		this.id = id;
		return this;
	}

	public Facility withNameSuffixAbbrev(String suffixAbbrev) {
		this.nameSuffixAbbrev = suffixAbbrev;
		return this;
	}

	public Facility withLiveline(LocalDate liveline) {
		this.liveline = liveline;
		return this;
	}

	public Facility withDeadline(LocalDate deadline) {
		this.deadline = deadline;
		return this;
	}

	public Facility withCreated(OffsetDateTime created) {
		this.created = created;
		return this;
	}

}
