package com.poststats.rs.api.model;

import java.math.BigInteger;
import java.time.OffsetDateTime;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonProperty.Access;
import com.poststats.rs.api.annotation.MapEntry;

/**
 * @author brian.long@poststats.com
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public class Photo extends BasePhoto<Photo> implements ReferenceablePhoto {

	@JsonProperty(required = true, access = Access.READ_ONLY)
	@MapEntry("photoID")
	private BigInteger id;

	@JsonProperty
	@MapEntry
	private String title;

	@JsonProperty
	@MapEntry
	private String description;

	@JsonProperty
	@MapEntry("mimetype")
	private String mimeType;

	@JsonProperty
	@MapEntry("bytes")
	private long size;

	@JsonProperty
	@MapEntry
	private boolean approved;

	@JsonProperty
	@MapEntry
	private boolean disabled;

	@JsonProperty
	@MapEntry
	private OffsetDateTime created;

	@Override
	public BigInteger getId() {
		return id;
	}

	public void setId(BigInteger id) {
		this.id = id;
	}

	public String getMimeType() {
		return mimeType;
	}

	public void setMimeType(String mimeType) {
		this.mimeType = mimeType;
	}

	public long getSize() {
		return size;
	}

	public void setSize(long size) {
		this.size = size;
	}

	public boolean isApproved() {
		return approved;
	}

	public void setApproved(boolean approved) {
		this.approved = approved;
	}

	public boolean isDisabled() {
		return disabled;
	}

	public void setDisabled(boolean disabled) {
		this.disabled = disabled;
	}

	public OffsetDateTime getCreated() {
		return created;
	}

	public void setCreated(OffsetDateTime created) {
		this.created = created;
	}

	public Photo withId(BigInteger id) {
		this.id = id;
		return this;
	}

	public Photo withMimeType(String mimeType) {
		this.mimeType = mimeType;
		return this;
	}

	public Photo withSize(long size) {
		this.size = size;
		return this;
	}

	public Photo withApproved(boolean approved) {
		this.approved = approved;
		return this;
	}

	public Photo withDisabled(boolean disabled) {
		this.disabled = disabled;
		return this;
	}

	public Photo withCreated(OffsetDateTime created) {
		this.created = created;
		return this;
	}

}
